do
	--- @class InnerScope
	local InnerScope = {}

	--[=[
		@param name type -- inner scope here

		A function inside a do end block!
	]=]
	function InnerScope:method(name) end
end

--[=[
	@class BeforeReturn

	A class before a return
]=]
return {}
